h1,
h2,
h3,
h4,
h5,
h6 {
    font-weight: normal;
}

h1 {
    line-height: 1.3em;
    font-size: 1.5em;
    text-transform: uppercase;
    color: $color-grey-1;
    font-weight: 600;

    span {
        text-transform: none;
        font-weight: 300;
    }

    .homepage & {
        text-transform: none;
    }
}

h2 {
    text-transform: uppercase;
    font-size: 1.3em;
    font-family: Open Sans;
    font-weight: 600;
    color: $color-grey-2;

    .page-explorer & {
        text-transform: none;
    }
}

p {
    margin-top: 0;
}

a {
    // @include transition(color 0.2s ease, background-color 0.2s ease);
    outline: none;
    color: $color-link;
    text-decoration: none;

    &:hover {
        color: $color-link-hover;
    }
}

a.underlined {
    border-bottom: 1px solid currentColor;
}

code {
    box-shadow: inset 0 0 4px 0 rgba(0, 0, 0, 0.2);
    background-color: $color-fieldset-hover;
    padding: 2px 5px;
}

kbd {
    border-radius: 3px;
    font-family: Open Sans, Arial, sans-serif;
    border: 1px solid $color-grey-2;
    border-color: rgba(0, 0, 0, 0.2);
    padding: 0.3em 0.5em;
}

dl,
dt,
dd {
    padding: 0;
    margin: 0;
}

dl {
    margin-top: 1em;
}

dt {
    color: darken($color-grey-3, 15%);
    text-transform: uppercase;
    font-size: 0.9em;
}

dd {
    margin-bottom: 1em;
}

.unbold {
    font-weight: normal;
}

// Help text formatters
.help-block {
    padding: 1em;
    margin: 1em 0;
    clear: both;
    color: $color-text-base;

    p {
        margin-top: 0;

        &:last-child {
            margin-bottom: 0;
        }
    }

    a {
        color: $color-teal;
    }
}

.help-info,
.help-warning,
.help-critical {
    border-radius: 3px;
    padding-left: 3.5em;
    position: relative;

    &:before {
        font-family: wagtail;
        position: absolute;
        left: 1em;
        top: 0.7em;
        content: '?';
        font-size: 1.4em;
    }
}

.help-info {
    background-color: lighten($color-blue, 30%);

    &:before {
        color: $color-blue;
    }
}

.help-warning {
    background-color: lighten($color-orange, 30%);

    &:before {
        color: $color-orange;
        content: '!';
    }
}

.help-critical {
    background-color: lighten($color-red, 40%);

    &:before {
        color: $color-red;
        content: '!';
    }
}

.u-para {
    margin-bottom: 1rem;
}
