{% load i18n %}

<script>
    $.fn.datetimepicker.defaults.i18n.wagtail_custom_locale = {
        months: [
            '{% trans "January" %}',
            '{% trans "February" %}',
            '{% trans "March" %}',
            '{% trans "April" %}',
            '{% trans "May" %}',
            '{% trans "June" %}',
            '{% trans "July" %}',
            '{% trans "August" %}',
            '{% trans "September" %}',
            '{% trans "October" %}',
            '{% trans "November" %}',
            '{% trans "December" %}'
        ],
        dayOfWeek: [
            '{% trans "Sunday" %}',
            '{% trans "Monday" %}',
            '{% trans "Tuesday" %}',
            '{% trans "Wednesday" %}',
            '{% trans "Thursday" %}',
            '{% trans "Friday" %}',
            '{% trans "Saturday" %}'
        ],
        dayOfWeekShort: [
            '{% trans "Sun" %}',
            '{% trans "Mon" %}',
            '{% trans "Tue" %}',
            '{% trans "Wed" %}',
            '{% trans "Thu" %}',
            '{% trans "Fri" %}',
            '{% trans "Sat" %}'
        ],
    }
    $.datetimepicker.setLocale('wagtail_custom_locale');
</script>
