// The wagtail font isn't available in WOFF2, so a @font-face is set here without a mixin.
@font-face {
    font-family: 'wagtail';
    src: url('#{$font-root}wagtail.woff') format('woff');
    font-weight: normal;
    font-style: normal;
}
