$icons: (
    'cogs': 'a',
    'doc-empty-inverse': 'b',
    'doc-empty': 'c',
    'edit': 'd',
    'arrow-up': 'e',
    'arrow-down': 'q',
    'search': 'f',
    'cross': 'g',
    'folder-open-1': 'i',
    'folder-inverse': 'j',
    'mail': 'k',
    'arrows-up-down': 'l',
    'locked': 'm',
    'arrow-right': 'n',
    'doc-full': 'h',
    'file-text-alt': 'h',
    'image': 'o',
    'picture': 'o',
    'unlocked': 'p',
    'doc-full-inverse': 'r',
    'folder': 's',
    'plus': 't',
    'tag': 'u',
    'folder-open-inverse': 'v',
    'cog': 'w',
    'tick': 'x',
    'user': 'y',
    'arrow-left': 'z',
    'tick-inverse': 'A',
    'plus-inverse': 'B',
    'snippet': 'D',
    'wagtail': 'V',
    'wagtail-inverse': '0',
    'bold': 'C',
    'italic': 'E',
    'undo': 'H',
    'repeat': 'I',
    'list-ol': 'G',
    'list-ul': 'F',
    'link': 'J',
    'radio-full': 'K',
    'radio-empty': 'L',
    'arrow-up-big': 'M',
    'arrow-down-big': 'N',
    'group': 'O',
    'media': 'P',
    'password': 'Q',
    'download': 'S',
    'order': 'T',
    'grip': 'U',
    'home': 'W',
    'order-down': 'X',
    'order-up': 'Y',
    'bin': 'Z',
    'spinner': '1',
    'pick': '2',
    'redirect': '3',
    'view': '4',
    'no-view': '^',
    'collapse-down': '5',
    'collapse-up': '6',
    'date': '7',
    'time': '8',
    'success': '9',
    'help': '?',
    'warning': '!',
    'form': '$',
    'site': '@',
    'placeholder': '{',
    'pilcrow': '\e600',
    'title': '\f034',
    'code': '\e601',
    'openquote': '“',
    'horizontalrule': '\2014',
    'chain-broken': '\e900',
    'table': '\f0ce',
    'logout': '\e901',
    'superscript': '\f12b',
    'subscript': '\f12c',
    'strikethrough': '\f0cc'
);

$icons-after: (
    'arrow-down-after': 'q',
    'arrow-up-after': 'e',
    'arrow-right-after': 'n'
);
