@import 'wagtailadmin/scss/variables';
@import 'wagtailadmin/scss/mixins';

.breadcrumb {
    margin: -1.2em 0 2em;
}

@include media-breakpoint-up(sm) {
    .breadcrumb {
        margin-top: -1.8em;
    }
}
