@import 'wagtailadmin/scss/variables-icons';

.icon.teal {
    color: $color-teal;
}

.icon.white {
    color: #fff;
}

.icon:before,
.icon:after,
.hallotoolbar [class^='icon-'],
.hallotoolbar [class*=' icon-']:before,
.hallotoolbar [class^='icon-']:before {
    @include icon(); // from _mixins.scss
}

.icon:after,
.hallotoolbar [class^='icon-']:after,
.hallotoolbar [class^='icon-']:after {
    text-align: right;
}

.hallotoolbar [class^='icon-'],
.hallotoolbar [class*=' icon-']:before,
.hallotoolbar [class*=' icon-']:before,
.hallotoolbar [class^='icon-']:before {
    vertical-align: -10%;
    margin-right: 0;
}


// =============================================================================
// Icon factory methods
// =============================================================================

@each $icon, $content in $icons {
    .icon-#{$icon}:before {
        content: quote(#{$content});
    }
}

@each $icon, $content in $icons-after {
    .icon-#{$icon}:after {
        content: quote(#{$content});
    }
}


// =============================================================================
// Custom config for various icons
// =============================================================================
.icon-download {
    // Credit: Icon made by Freepik from Flaticon.com
}

.icon-view:before,
.icon-no-view:before {
    vertical-align: -3.5px;
    font-size: 1.1rem;
}

.icon-view:before {
    content: '4';
}

.icon-no-view:before {
    content: '^';
}

.icon-collapse-down:before {
    content: '5';
}

.icon-collapse-up:before {
    content: '6';
}

.icon-date:before {
    content: '7';
}

.icon-time:before {
    content: '8';
}


.icon-spinner:after,
.icon-spinner:before {
    width: 1em;
    animation: spin 0.5s infinite linear;
    display: inline-block;
    // content: '1';
}

.icon-horizontalrule:before {
    font-family: Open Sans, Arial, sans-serif;
}


.icon-larger:before {
    font-size: 1.5em;
}

.icon.text-replace {
    font-size: 0;
    line-height: 0;
    overflow: hidden;

    &:before {
        margin-right: 0;
        font-size: 1rem;
        display: inline-block;
        width: 100%;
        line-height: 1.2em;
        text-align: center;
        vertical-align: middle;
    }
}

@keyframes spin {
    0% {
        transform: rotate(0deg);
    }

    100% {
        transform: rotate(360deg);
    }
}



.icon-spinner:after {
    display: inline-block;
    line-height: 1;
}

// CSS-only circled question mark.
// <span class="icon-help-inverse" aria-hidden="true"></span>
.icon-help-inverse {
    $size: 15px;

    &:before {
        content: '?';
        display: inline-block;
        width: $size;
        height: $size;
        line-height: $size;
        font-size: 1.1em;
        text-align: center;
        border-radius: 100%;
        color: $color-grey-2;
        border: 1px solid currentColor;
    }
}
